import os
from celery import Celery
from django.conf import settings
import logging

# 设置Django默认settings模块
os.environ.setdefault('DJANGO_SETTINGS_MODULE', 'daren.settings')

# 创建日志记录器
logger = logging.getLogger(__name__)

# 在应用启动时检查Redis连接
def check_redis_connection():
    try:
        import redis
        from django.conf import settings
        
        # 从CELERY_BROKER_URL解析Redis连接信息
        broker_url = settings.CELERY_BROKER_URL
        host = '127.0.0.1'  # 默认
        port = 6379         # 默认
        db = 0              # 默认
        
        # 简单解析broker_url (格式如: redis://127.0.0.1:6379/0)
        if broker_url.startswith('redis://'):
            parts = broker_url[8:].split('/')
            if len(parts) > 1:
                db = int(parts[1])
            
            host_port = parts[0].split(':')
            host = host_port[0]
            if len(host_port) > 1:
                port = int(host_port[1])
        
        # 尝试连接
        r = redis.Redis(host=host, port=port, db=db, socket_timeout=10)
        r.ping()
        logger.info(f"成功连接到Redis服务器: {host}:{port}")
        return True, None
    except Exception as e:
        error_msg = f"无法连接到Redis服务器: {str(e)}"
        logger.error(error_msg)
        return False, error_msg

# 检查Redis连接
redis_ok, redis_error = check_redis_connection()
if not redis_ok:
    logger.critical(f"无法启动Celery，Redis连接失败: {redis_error}")
    print(f"\n\n[Celery错误] Redis连接失败: {redis_error}\n")
    print("请确保Redis服务正在运行，并且配置正确。如果问题仍然存在，请尝试修改settings.py中的CELERY_BROKER_URL。\n\n")

# 创建Celery应用
app = Celery('daren')

# 使用Django settings的CELERY_配置值
app.config_from_object('django.conf:settings', namespace='CELERY')

# 自动发现并注册tasks模块中的任务
app.autodiscover_tasks()

@app.task(bind=True, ignore_result=True)
def debug_task(self):
    print(f'Request: {self.request!r}') 